#
# spec file for package libmlt
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ffmpeg
# Dan Dennedy asked to disable it since it's buggy and unmaintained (see e.g. http://www.kdenlive.org/mantis/view.php?id=3070)
%bcond_with vdpau

# vidstab currently can't enter Factory due to legal review / unclarity. Temp disable
%bcond_with vidstab

%define _name mlt
%define libname lib%{_name}
%define soname 6

%define _name_pp %{_name}++
%define libname_pp lib%{_name_pp}
%define soname_pp 3

Name:           %{libname}
Version:        0.9.6
Release:        57.1
Summary:        Multimedia framework designed and developed for television broadcasting
License:        GPL-3.0+
Group:          System/Libraries
Url:            http://%{_name}.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/%{_name}/%{_name}/%{_name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE libmlt-0.8.2-vdpau.patch reddwarf@opensuse.org -- Make VDPAU support work without the devel package
Patch1:         libmlt-0.8.2-vdpau.patch
# PATCH-FIX-UPSTREAM use-recommended-freetype-include.patch -- Freetype upstream recommends using their macros together with
# ft2build include. Positive sideeffect is that this patch makes it build with both freetype2 2.5.1, and older versions
Patch2:         use-recommended-freetype-include.patch
BuildRequires:  gcc-c++
BuildRequires:  ladspa-devel
BuildRequires:  pkg-config
%if 0%{?suse_version} > 1320
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Xml)
%else
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtSvg)
BuildRequires:  pkgconfig(QtXml)
%endif
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(frei0r)
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libdv)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libquicktime)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangoft2)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(sox)
%if %{with vidstab}
BuildRequires:  pkgconfig(vidstab)
%endif
BuildRequires:  pkgconfig(vorbisfile)
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
%if %{with vdpau}
BuildRequires:  pkgconfig(vdpau)
# VDPAU support requires it
BuildRequires:  pkgconfig(x11)
%endif
%endif

%description
MLT is an open source multimedia framework, designed and developed for
television broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of applications.
The functionality of the system is provided via an assortment of ready to use
tools, XML authoring components, and an extensible plug-in based API.

%package -n %{libname}%{soname}
Summary:        Multimedia framework designed and developed for television broadcasting
Group:          System/Libraries
Recommends:     %{libname}%{soname}-data
Recommends:     %{libname}%{soname}-modules

%description -n %{libname}%{soname}
MLT is an open source multimedia framework, designed and developed for
television broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of applications.
The functionality of the system is provided via an assortment of ready to use
tools, XML authoring components, and an extensible plug-in based API.

%package devel
Summary:        Multimedia framework designed and developed for television broadcasting
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{soname} = %{version}

%description devel
MLT is an open source multimedia framework, designed and developed for
television broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of applications.
The functionality of the system is provided via an assortment of ready to use
tools, XML authoring components, and an extensible plug-in based API.

%package -n %{libname_pp}%{soname_pp}
Summary:        Multimedia framework designed and developed for television broadcasting
Group:          System/Libraries

%description -n %{libname_pp}%{soname_pp}
MLT is an open source multimedia framework, designed and developed for
television broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of applications.
The functionality of the system is provided via an assortment of ready to use
tools, XML authoring components, and an extensible plug-in based API.

%package -n %{libname_pp}-devel
Summary:        Multimedia framework designed and developed for television broadcasting
Group:          Development/Libraries/C and C++
Requires:       %{libname_pp}%{soname_pp} = %{version}
Requires:       %{libname}-devel = %{version}

%description -n %{libname_pp}-devel
MLT is an open source multimedia framework, designed and developed for
television broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of applications.
The functionality of the system is provided via an assortment of ready to use
tools, XML authoring components, and an extensible plug-in based API.

%package -n melt%{soname}
Summary:        Multimedia framework designed and developed for television broadcasting
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       melt

%description -n melt%{soname}
MLT is an open source multimedia framework, designed and developed for
television broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of applications.
The functionality of the system is provided via an assortment of ready to use
tools, XML authoring components, and an extensible plug-in based API.

%package -n melt
Summary:        Multimedia framework designed and developed for television broadcasting
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       melt%{soname}
Conflicts:      melt > %{version}
Conflicts:      melt < %{version}

%description -n melt
MLT is an open source multimedia framework, designed and developed for
television broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of applications.
The functionality of the system is provided via an assortment of ready to use
tools, XML authoring components, and an extensible plug-in based API.

%package -n %{libname}%{soname}-modules
Summary:        Multimedia framework designed and developed for television broadcasting
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{_bindir}/melt
Requires:       %{libname}%{soname} = %{version}
Recommends:     frei0r-plugins
%if %{with ffmpeg}
Provides:       mlt(%{soname})(avformat)
%if %{with vdpau}
# I would recommend it, but to the best of my knowledge nobody but nvidia provides a backend
Suggests:       %(rpm -qf $(readlink -e %{_libdir}/libvdpau.so) --qf '%{NAME}')
%endif
%endif

%description -n %{libname}%{soname}-modules
MLT is an open source multimedia framework, designed and developed for
television broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of applications.
The functionality of the system is provided via an assortment of ready to use
tools, XML authoring components, and an extensible plug-in based API.

%package -n %{libname}%{soname}-data
Summary:        Multimedia framework designed and developed for television broadcasting
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{libname}%{soname} = %{version}
BuildArch:      noarch

%description -n %{libname}%{soname}-data
MLT is an open source multimedia framework, designed and developed for
television broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of applications.
The functionality of the system is provided via an assortment of ready to use
tools, XML authoring components, and an extensible plug-in based API.

%package -n python-%{_name}
Summary:        Python bindings for MLT
Group:          Development/Languages/Python
BuildRequires:  python-devel
BuildRequires:  swig
Requires:       %{libname_pp}%{soname_pp} >= %{version}
Requires:       %{libname}%{soname} >= %{version}
%{py_requires}
Provides:       python-%{_name}%{soname}

%description -n python-%{_name}
This package is needed to use MLT from Python.

%prep
%setup -q -n %{_name}-%{version}
%patch1
%patch2 -p1

# To complement libmlt-0.8.0-vdpau.patch.
# When vdpau support is not compiled it will break the code. Doesn't matter because the code will not be used anyway.
VDPAU_SONAME=$(objdump -p $(readlink -e %{_libdir}/libvdpau.so) | grep SONAME | sed 's/.*SONAME.* //' | tr -d '\n')
sed "s/__VDPAU_SONAME__/${VDPAU_SONAME}/" -i src/modules/avformat/vdpau.c

%build
%configure \
%ifnarch %{ix86} x86_64
  --disable-mmx \
  --disable-sse \
  --disable-sse2 \
%endif
--enable-gpl --enable-gpl3 \
%ifarch i586
--disable-mmx \
%endif
%if %{with ffmpeg}
%if %{with vdpau}
--avformat-vdpau \
%endif
%endif
--enable-extra-versioning \
--swig-languages=python
make %{?_smp_mflags}

%install
%make_install
install -Dpm 0644 docs/melt.1 %{buildroot}%{_mandir}/man1/melt%{soname}.1
ln -s melt%{soname}.1 %{buildroot}%{_mandir}/man1/melt.1
install -Dpm 0644 src/swig/python/_%{_name}.so '%{buildroot}%{python_sitearch}/_%{_name}.so'
install -Dpm 0644 src/swig/python/%{_name}.py '%{buildroot}%{python_sitearch}/%{_name}.py'

# Get the modules that need data
for MODULE in %{buildroot}%{_libdir}/mlt-%{soname}/libmlt*.so; do
  echo $MODULE
  MODULEDIR=%{_datadir}/mlt-%{soname}/$(echo $MODULE | sed 's|%{buildroot}%{_libdir}/mlt-%{soname}/libmlt\(.*\).so|\1|')
  echo $MODULEDIR
  if [ -e %{buildroot}$MODULEDIR ]; then
    echo Done $MODULEDIR
    echo $MODULEDIR >> module_data.dirs
  fi;
done

# Pure data modules
for MODULE in feeds lumas; do
    echo %{_datadir}/mlt-%{soname}/$MODULE >> module_data.dirs
done

# Remove the unversioned symbolic links
rm -f %{buildroot}%{_libdir}/mlt
rm -f %{buildroot}%{_datadir}/mlt

%post -n %{libname}%{soname} -p /sbin/ldconfig

%postun -n %{libname}%{soname} -p /sbin/ldconfig

%post -n %{libname_pp}%{soname_pp} -p /sbin/ldconfig

%postun -n %{libname_pp}%{soname_pp} -p /sbin/ldconfig

%files -n %{libname}%{soname}
%defattr(0644, root, root, 0755)
%doc AUTHORS ChangeLog COPYING GPL GPLv3 NEWS README
%{_libdir}/lib%{_name}.so.%{soname}
%{_libdir}/lib%{_name}.so.%{version}

%files devel
%defattr(0644, root, root, 0755)
%{_libdir}/lib%{_name}.so
%{_includedir}/%{_name}
%{_libdir}/pkgconfig/%{_name}-framework.pc

%files -n %{libname_pp}%{soname_pp}
%defattr(0644, root, root, 0755)
%{_libdir}/lib%{_name_pp}.so.%{soname_pp}
%{_libdir}/lib%{_name_pp}.so.%{version}

%files -n %{libname_pp}-devel
%defattr(0644, root, root, 0755)
%{_libdir}/lib%{_name_pp}.so
%{_includedir}/%{_name_pp}
%{_libdir}/pkgconfig/%{_name_pp}.pc

%files -n melt%{soname}
%defattr(0644, root, root, 0755)
%attr(0755, root, root) %{_bindir}/melt%{soname}
%{_mandir}/man1/melt%{soname}.1%{ext_man}

%files -n melt
%defattr(0644, root, root, 0755)
%{_bindir}/melt
%{_mandir}/man1/melt.1%{ext_man}

%files -n %{libname}%{soname}-modules -f module_data.dirs
%defattr(0644, root, root, 0755)
%{_libdir}/%{_name}-%{soname}/
%dir %{_datadir}/%{_name}-%{soname}/

%files -n %{libname}%{soname}-data
%defattr(0644, root, root, 0755)
%dir %{_datadir}/%{_name}-%{soname}/
%{_datadir}/%{_name}-%{soname}/metaschema.yaml
%{_datadir}/%{_name}-%{soname}/profiles/
%{_datadir}/%{_name}-%{soname}/presets/
%if %{with vidstab}
%{_datadir}/%{_name}-%{soname}/vid.stab/
%endif

%files -n python-%{_name}
%defattr(0644, root, root, 0755)
%{python_sitearch}/_%{_name}.so
%{python_sitearch}/%{_name}.py

%changelog
* Sun Apr 19 2015 tittiatcoke@gmail.com
- libmlt for Tumbleweed/Factory is now QT5 based !!
- Update to 0.9.6
  + Framework
  * Added color_trc (transfer characteristic) property to mlt_consumer and mlt_frame.
  * Added Mlt::Profile::set_display_aspect(int, int).
  * Added mlt_pool_stat().
  * Added mlt_smpte_df and mlt_smpte_ndf to mlt_time_format for non-drop-frame timecode support.
  * Added Mlt::Tractor::Tractor(Mlt::Profile&).
  * Added mlt_frame_get_alpha().
  * Added default, copy, and assignment methods to Mlt::Frame.
  * Added Mlt::Filter::process(Mlt::Frame&).
  + Modules
  * Added support for color_trc property to avformat and opengl modules.
  * Performance improvements for composite and matte transitions.
  * Added fill, halign, and valign properties to affine transition and filter.
  * Added producer.* and consumer.* properties to consumer producer.
  * Fixes for libavformat and libavcodec v56.
  * Dropped support for FFmpeg < v1.0 and Libav < v9.
  * Added a lumakey filter.
  * Added a localtime property to dynamictext filter.
  * Added date/time format string support to dynamictext filter.
  * Added no_root property to xml consumer.
  * Added audio-only tone producer.
  * Added drop property to count producer.
  * Added caching to pango producer to improve performance.
  + Other
  * Added WMV and WMA avformat consumer presets.
  * Added a ProRes-Kostya avformat consumer preset.
  * Changed VP9 WebM preset to use Opus audio codec.
  * Added 4K UHD and 2.5K QHD profiles.
  * Added x265-medium and x265-medium-pass1 avformat consumer presets.
  * Added a unit test for Mlt::Frame.
- Drop upstreamed patches
  * mlt-0.9.2-Add-missing-stdlib-include-for-getenv.patch
* Tue Nov 11 2014 dimstar@opensuse.org
- Temporarly disabled vid.stab support, as the submission to
  Tumbleweed hit a legal road bump. While it's enabled in the devel
  project, other packages depending on libmlt are being blocked.
* Tue Nov  4 2014 olaf@aepfle.de
- Enable exif support
- Add missing stdlib.h inclusion in qt
  (mlt-0.9.2-Add-missing-stdlib-include-for-getenv.patch)
* Sat Oct 25 2014 reddwarf@opensuse.org
- Add vid.stab support
  Add BuildRequires: pkgconfig(vidstab)
* Thu Oct 16 2014 nico.kruber@gmail.com
- Update to 0.9.2
  + Framework
  * Added "boolean" parameter type and "argument" parameter
    attribute to service metadata schema.
  * Added mlt_properties_frames_to_time().
  * Added mlt_properties_time_to_frames().
  * Changed mlt_events_fire() to return the number of listeners.
  * Added consumer-thread-create and consumer-thread-join events.
  * Added LC_NUMERIC handling for Windows.
  * Added mlt_playlist_mix_out() and mlt_playlist_mix_in().
  * Added mlt_properties_from_utf8().
  + Modules
  * Renamed "qimage" module to "qt".
  * Added support for Qt 5.
  * Added qtext producer, which is now prefered by dynamictext
    filter over pango.
  * Added xml-nogl consumer.
  * Consolidated dgraft, burningtv, and rotoscoping into new
    plusgpl module.
  * Added vid.stab module with vidstab and deshake filters. This
    depends on external vid.stab library unlike its predecessors.
  * Rewrote opengl module.
  * Added loudness filter based on EBU R128.
  * Added rgblut filter to plus module.
  * Added luma-only liftgammagain filter to plusgpl module.
  * Added lift_gamma_gain filter to plus module.
  * Added support new keyframable animated properties to brightness,
    volume, panner, boxblur, wave, sepia, charcoal, burn, gamma,
    grain, dust, lines, tcolor, oldfilm.
  * Added movit.luma transition to opengl module.
  * Added cbrts consumer to plusgpl module.
  * Removed the "ppm" PPM-pipe producer.
  * Added more VITC functionality to decklink module.
  * Added matte transition to core module.
  + DEPRECATION WARNINGS
  * Deprecate videostab module with videostab and videostab filters.
    This will not be removed soon in order to keep old scripts and
    projects functional.
  * Deprecate the dv (libdv), kino, and vorbis modules. These are
    scheduled to be removed in next release.
- Update use-recommended-freetype-include.patch
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Added use-recommended-freetype-include.patch -- Freetype upstream
  recommends using their macros together with ft2build include.
  Positive sideeffect is that this patch makes it build with both
  freetype2 2.5.1, and older version
* Sun Jun 30 2013 tittiatcoke@gmail.com
- Update to 0.9.0
  * new, properly integrated property animation API
  * Improved pause behavior when using buffered rendering in
    mlt_consumer.
  * Added mlt_color type.
  * Deprecated mlt_geometry API.
  * Support for the latest versions of FFmpeg and Libav (but
    dropping support for 0.5 and 0.6 versions).
  * Added alpha channel output to avformat consumer.
  * Added reconnect and exit_on_disconnect properties to avformat
    producer.
  * Added qglsl consumer to use opengl with avformat, sdi, and
    decklink.
  * Added avsync module with blipflash producer and consumer for
    testing.
  * Added new "count" producer to gtk2 module.
  * Changed frei0r to use index-based property names making it
    impervious to param name changes (param name still accepted
    for compatibility).
  * Added default parameter values to frei0r metadata.
  * Added more python example web services.
  * Started a unit test suite.
- Dropped patch libmlt-0.8.0-versioned_dirs.patch due to upstream
  support for versioning (--enable-extra-versioning configure flag)
* Thu May  2 2013 reddwarf@opensuse.org
- By default disable VDPAU as requested by Dan Dennedy
* Fri Apr 19 2013 tiwai@suse.de
- Fix missing buildrequire for alsa-devel
* Mon Jan 21 2013 reddwarf@opensuse.org
- Update to 0.8.8
  * Purely a bugfix release
* Fri Nov 30 2012 reddwarf@opensuse.org
- Make multiple versions of melt parallel installable
* Tue Nov 27 2012 crrodriguez@opensuse.org
- Fix build in non-x86 platforms (ARM, PPC ETC..)
* Thu Nov 15 2012 reddwarf@opensuse.org
- Update to 0.8.6
  * Fix a performance regression on videos that use full-range
    colorspaces such as yuv420p.
* Wed Nov 14 2012 reddwarf@opensuse.org
- Update to 0.8.4
  * Added playlist-next event and PlaylistNextListener to Ruby binding
  * FFmpeg 1.0 and libAV master compatibility
  * Improvements to motion_est filter to generate keyframes for apps
  * Added audiolevel (measurement) filter
- Remove libmlt-0.8.2-ffmpeg1.patch and libmlt-0.8.0-optflags.patch.
  Have been applied upstream.
* Mon Oct  1 2012 reddwarf@opensuse.org
- Add libmlt-0.8.2-ffmpeg1.patch to fix build with ffmpeg 1.0
* Thu Aug 30 2012 reddwarf@opensuse.org
- Update to 0.8.2
  * Overhaul of A/V sync with libavformat-based inputs.
  * Fix a major memory leak introduced in previous release.
  * Fixes to problems revealed by Coverity Scan static analysis.
  * Improved encoding presets.
  * melt can now be built without SDL with define MELT_NOSDL, which is handy
    for running it as a child process on Windows and OS X.
  * melt can now be signaled to quit, which also makes it more useful as a
    child process.
- Rebase libmlt-0.8.2-vdpau.patch
- Remove libmlt-0.8.0-fix_null_pointer_dereference.patch. Applied upstream.
* Mon Aug 27 2012 toddrme2178@gmail.com
- Added libmlt-0.8.0-fix_null_pointer_dereference.patch, fixed
  upstream.  See and BNC # 777416 and upstream comit
  17a64a9aa20aa27861b6169e38859358a323c5a8
* Sat Aug 25 2012 reddwarf@opensuse.org
- Make python-mlt require at least the same version of libmlt++
* Fri Aug 17 2012 reddwarf@opensuse.org
- Make vdpau support work without the need of the devel package
* Thu Aug 16 2012 reddwarf@opensuse.org
- Package module specific data in the -modules subpackage
* Sun Aug 12 2012 reddwarf@opensuse.org
- Add modules and data directories as variables in the .pc file
* Tue Aug  7 2012 reddwarf@opensuse.org
- Version modules and data directories
- Put the full python module in %%python_sitearch
- Added "mlt(%%{soname})(avformat)" and "python-%%{_name}%%{soname}"
  provides to help openshot select the versions it needs
* Sat Aug  4 2012 reddwarf@opensuse.org
- Compile the python binding with %%{optflags}, getting debug
  information on the way.
- Fix VDPAU support
* Mon Jun 18 2012 reddwarf@opensuse.org
- Update to 0.8.0
  + Addition of time properties
  + ABI incompatible changes to some mlt_property functions
  + Improve seek speed on AVCHD when using FFmpeg v0.9.1+ (NOT
    Libav!)
  + Composite and dissolve speed improvements on x86-64
  + Improve performance of caching in image producers
  + Add device enumeration to decklink producer and consumer
- Remove included copy of GPLv3, upstream added it
- Remove dependency to x11 when unneeded
- Enable VDPAU support in the avformat module
* Tue Mar 27 2012 idonmez@suse.com
- Set license to GPLv3 for discussion in bnc#753622
* Sat Mar 10 2012 idonmez@suse.com
- Drop swfdec dependency, swfdec is not maintained.
* Thu Feb 23 2012 reddwarf@opensuse.org
- Update to 0.7.8
* Sun Jan  2 2011 reddwarf@opensuse.org
- Initial package
